@@ -1,4 +1,4 @@
-/* $OpenBSD: netcat.c,v 1.226 2023/08/14 08:07:27 tb Exp $ */
+/* $OpenBSD: netcat.c,v 1.229 2024/11/02 17:19:27 tb Exp $ */
 /*
  * Copyright (c) 2001 Eric Jackson <ericj@monkey.org>
  * Copyright (c) 2015 Bob Beck.  All rights reserved.
@@ -237,7 +237,7 @@ ssize_t fillbuf(int, unsigned char *, size_t *);
 
 char *proto_name(int, int);
 static int connect_with_timeout(int, const struct sockaddr *, socklen_t, int);
-static void quit();
+static void quit(int sig);
 
 int
 main(int argc, char *argv[])
@@ -838,10 +838,6 @@ main(int argc, char *argv[])
 				close(connfd);
 #endif
 			}
-			if (family == AF_UNIX && uflag) {
-				if (connect(s, NULL, 0) == -1)
-					err(1, "connect");
-			}
 
 			if (!kflag) {
 				if (s != -1)
@@ -1035,7 +1031,7 @@ timeout_tls(int s, struct tls *tls_ctx, int (*func)(struct tls *))
 	struct pollfd pfd;
 	int ret;
 
-	while ((ret = (*func)(tls_ctx)) != 0) {
+	while ((ret = func(tls_ctx)) != 0) {
 		if (ret == TLS_WANT_POLLIN)
 			pfd.events = POLLIN;
 		else if (ret == TLS_WANT_POLLOUT)
@@ -1789,7 +1785,7 @@ fdpass(int nfd)
 	memset(&cmsgbuf, 0, sizeof(cmsgbuf));
 	memset(&iov, 0, sizeof(iov));
 
-	mh.msg_control = (caddr_t)&cmsgbuf.buf;
+	mh.msg_control = &cmsgbuf.buf;
 	mh.msg_controllen = sizeof(cmsgbuf.buf);
 	cmsg = CMSG_FIRSTHDR(&mh);
 	cmsg->cmsg_len = CMSG_LEN(sizeof(int));
@@ -2348,7 +2344,7 @@ usage(int ret)
  * quit()
  * handler for a "-q" timeout (exit 0 instead of 1)
  */
-static void quit()
+static void quit(__attribute__((unused)) int sig)
 {
 	exit(0);
 }
